summaryrefslogtreecommitdiffstats
path: root/kio/kio/tcpslavebase.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/tcpslavebase.cpp')
-rw-r--r--kio/kio/tcpslavebase.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kio/kio/tcpslavebase.cpp b/kio/kio/tcpslavebase.cpp
index 144aaa6b1..78093577d 100644
--- a/kio/kio/tcpslavebase.cpp
+++ b/kio/kio/tcpslavebase.cpp
@@ -223,7 +223,7 @@ if ((m_bIsSSL || d->usingTLS) && !d->useSSLTunneling) { // SSL CASE
return -1;
}
- bytes = rc; // in case it tqcontains no \n
+ bytes = rc; // in case it contains no \n
for (int i = 0; i < rc; i++) {
if (tmpbuf[i] == '\n') {
bytes = i+1;
@@ -774,7 +774,7 @@ int TCPSlaveBase::verifyCertificate()
}
#endif
if (!_IPmatchesCN && !d->militantSSL) { // force this if the user wants it
- if (d->cc->getHostList(pc).tqcontains(ourHost)) {
+ if (d->cc->getHostList(pc).contains(ourHost)) {
_IPmatchesCN = true;
}
}